@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: libmpd
-version: 0.5.0
-id: libmpd-0.5.0-fc792692adcbae688e3d459686d78492
+version: 0.6.0
+id: libmpd-0.6.0-532ce7b9971e660cab01691291dc1afc
 
 license: LGPL
-copyright: Ben Sinclair 2005-2009, Joachim Fasting 2010
+copyright: Ben Sinclair 2005-2009, Joachim Fasting 2010, 2011
 maintainer: Joachim Fasting <joachim.fasting@gmail.com>
 stability: beta
 homepage: http://github.com/joachifm/libmpd-haskell
@@ -22,26 +22,26 @@ hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                 Network.MPD.Commands.Parse Network.MPD.Commands.Query
                 Network.MPD.Commands.Types Network.MPD.Commands.Util
                 Network.MPD.Utils
-import-dirs: /usr/local/lib/ghc/libmpd-0.5.0
-library-dirs: /usr/local/lib/ghc/libmpd-0.5.0
-hs-libraries: HSlibmpd-0.5.0
+import-dirs: /usr/local/lib/ghc/libmpd-0.6.0
+library-dirs: /usr/local/lib/ghc/libmpd-0.6.0
+hs-libraries: HSlibmpd-0.6.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
-         containers-0.3.0.0-ee442470d8dcc9e45f31677c400c5379
-         filepath-1.1.0.4-c303c646a99c2a24d2402008d247eb5f
-         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
-         network-2.2.1.7-194f6443d68f3341443f88ff72345c9e
-         old-locale-1.0.0.2-0c1a4b40f2d3b9f6b725f54c00fe0923
-         time-1.1.4-d9f7b7932dc3a4863006ed6b1d525856
-         utf8-string-0.3.6-68d380e8d21ac9d6339e67a29e33e6d9
+depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
+         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
+         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
+         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
+         network-2.3.0.2-51cd64b57afa0471aa34f65914adc9bc
+         old-locale-1.0.0.2-6e2a3c0744e8cf4e0ac2d4e58659f7b5
+         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
+         utf8-string-0.3.6-41fffa08ae1349e9fe1e9be7575781f1
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.5.0/html/libmpd.haddock
-haddock-html: /usr/local/share/doc/hs-libmpd-0.5.0/html
+haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.6.0/html/libmpd.haddock
+haddock-html: /usr/local/share/doc/hs-libmpd-0.6.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
